package com.example.firstapp.adapter

import android.view.LayoutInflater
import android.view.ViewGroup
import androidx.recyclerview.widget.DiffUtil
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.ListAdapter
import androidx.recyclerview.widget.RecyclerView
import com.example.firstapp.R
import com.example.firstapp.databinding.ItemFinanceBinding
import com.example.firstapp.databinding.ItemFinanceGroupBinding
import com.example.firstapp.databinding.ItemFinancePackageHomeBinding
import com.example.firstapp.model.FinanceGroup
import com.example.firstapp.model.FinancePackage

class FinanceAdapter :
    ListAdapter<FinanceGroup, FinanceAdapter.ViewHolder>(FinanceGroupDiffCallback()) {

    private var onPackageClickListener: (FinanceGroup, FinancePackage) -> Unit = { _, _ -> }

    fun setOnPackageClickListener(listener: (FinanceGroup, FinancePackage) -> Unit) {
        onPackageClickListener = listener
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolder {
        val binding = ItemFinanceGroupBinding.inflate(
            LayoutInflater.from(parent.context), parent, false
        )
        return ViewHolder(binding)
    }

    override fun onBindViewHolder(holder: ViewHolder, position: Int) {
        val group = getItem(position)
        holder.bind(group)
        holder.setOnPackageClickListener(onPackageClickListener)
    }


    inner class ViewHolder(private val binding: ItemFinanceGroupBinding) :
        RecyclerView.ViewHolder(binding.root) {
        private val packagesAdapter = FinancePackageHomeAdapter { pack ->
            currentGroup?.let { group ->
                onPackageClickListener(group, pack)
            }
        }
        private var currentGroup: FinanceGroup? = null

        init {
            binding.rvPackages.apply {
                layoutManager = LinearLayoutManager(context)
                adapter = packagesAdapter
            }
        }

        fun bind(group: FinanceGroup) {
            currentGroup = group
            binding.tvStationName.text = group.stationName
            binding.tvPackageCount.text = "共${group.packages.size}笔账单"
            packagesAdapter.submitList(group.packages)
        }

        fun setOnPackageClickListener(listener: (FinanceGroup, FinancePackage) -> Unit) {
            // 这个方法可以移除，因为我们在构造 ExpressPackageHomeAdapter 时已经处理了点击事件
            // 或者保留这个方法但不做任何操作
        }
    }
}

// 首页使用的包裹适配器 - 简化版本
class FinancePackageHomeAdapter(private val onPackageClick: (FinancePackage) -> Unit) :
    ListAdapter<FinancePackage, FinancePackageHomeAdapter.ViewHolder>(FinancePackageDiffCallback()) {

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolder {
        val binding = ItemFinancePackageHomeBinding.inflate(
            LayoutInflater.from(parent.context), parent, false
        )
        return ViewHolder(binding)
    }

    override fun onBindViewHolder(holder: ViewHolder, position: Int) {
        val pack = getItem(position)
        holder.bind(pack)
    }

    inner class ViewHolder(private val binding: ItemFinancePackageHomeBinding) :
        RecyclerView.ViewHolder(binding.root) {

        init {
            binding.root.setOnClickListener {
                val pack = getItem(adapterPosition)
                onPackageClick(pack)
            }
        }

        fun bind(pack: FinancePackage) {
            binding.tvCompany.text = pack.company
            binding.tvCreateTime.text = pack.createTime
            binding.tvTrackingNumber.text = pack.trackingNumber
        }
    }
}

// 取件页面使用的包裹适配器
class FinancePackageAdapter(private val onPackagePickup: (FinancePackage) -> Unit = { _ -> }) :
    ListAdapter<FinancePackage, FinancePackageAdapter.ViewHolder>(FinancePackageDiffCallback()) {

    private var onPackageClickListener: (FinancePackage) -> Unit = {}
    private var stationName: String = ""

    fun setStationInfo(station: String) {
        stationName = station
    }

    fun setOnPackageClickListener(listener: (FinancePackage) -> Unit) {
        onPackageClickListener = listener
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolder {
        val binding = ItemFinanceBinding.inflate(
            LayoutInflater.from(parent.context), parent, false
        )
        return ViewHolder(binding)
    }

    override fun onBindViewHolder(holder: ViewHolder, position: Int) {
        val pack = getItem(position)
        holder.bind(pack)
    }

    inner class ViewHolder(private val binding: ItemFinanceBinding) :
        RecyclerView.ViewHolder(binding.root) {

        init {
            binding.ivPackageStatus.setOnClickListener {
                val pack = getItem(adapterPosition)
                onPackagePickup(pack)
            }

            binding.root.setOnClickListener(null)
        }

        fun bind(pack: FinancePackage) {
            binding.tvPackageId.text = pack.id.toString()
            binding.tvCompany.text = pack.company
            binding.tvCreateTime.text = pack.createTime
            binding.tvTrackingNumber.text = pack.trackingNumber
            binding.ivPackageStatus.setImageResource(
//                if (pack.isPickedUp) R.drawable.circle_checked
//                else R.drawable.circle
                R.drawable.circle
            )
        }
    }
}


private class FinanceGroupDiffCallback : DiffUtil.ItemCallback<FinanceGroup>() {
    override fun areItemsTheSame(oldItem: FinanceGroup, newItem: FinanceGroup): Boolean {
        return oldItem.stationName == newItem.stationName
    }

    override fun areContentsTheSame(oldItem: FinanceGroup, newItem: FinanceGroup): Boolean {
        return oldItem == newItem
    }
}

private class FinancePackageDiffCallback : DiffUtil.ItemCallback<FinancePackage>() {
    override fun areItemsTheSame(oldItem: FinancePackage, newItem: FinancePackage): Boolean {
        return oldItem.trackingNumber == newItem.trackingNumber
    }

    override fun areContentsTheSame(oldItem: FinancePackage, newItem: FinancePackage): Boolean {
        return oldItem == newItem
    }
}